<?php

namespace common\logic\Order\Order\Repository;

use common\logic\AbstractRepositoryQuery;
use common\logic\Order\Order\Service\OrderDefinition;
use common\logic\User\User\Model\User;

class OrderRepositoryQuery extends AbstractRepositoryQuery
{
    protected OrderDefinition $definition;

    public function loadDependencies(): void
    {
        $this->loadDefinition(OrderDefinition::class);
    }

    public function filterById(int $id): self
    {
        $this->andWhere(['order.id' => $id]);

        return $this;
    }

    public function filterByDistributionDate(string $date): self
    {
        $this->andWhere(['distribution.date' => $date]);

        return $this;
    }

    public function filterIsValid(): self
    {
        $this->andWhere('date_delete IS NULL');

        return $this;
    }

    public function filterByUser(User $user): self
    {
        $this->andWhere(['order.id_user' => $user->id]);

        return $this;
    }

    public function filterIsIncoming(): self
    {
        $this->andWhere('distribution.date >= :date_today')
            ->params([':date_today' => date('Y-m-d')]);

        return $this;
    }

    public function filterIsPassed(): self
    {
        $this->andWhere('distribution.date < :date_today')
            ->params([':date_today' => date('Y-m-d')]);

        return $this;
    }
}